.. Copyright (C) 2024- Davide Mollica <davide.mollica@inaf.it>
.. SPDX-License-Identifier: GPL-3.0-or-later
..
.. This file is part of iactsim.
..
.. iactsim is free software: you can redistribute it and/or modify
.. it under the terms of the GNU General Public License as published by
.. the Free Software Foundation, either version 3 of the License, or
.. (at your option) any later version.
..
.. iactsim is distributed in the hope that it will be useful,
.. but WITHOUT ANY WARRANTY; without even the implied warranty of
.. MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.. GNU General Public License for more details.
..
.. You should have received a copy of the GNU General Public License
.. along with iactsim.  If not, see <https://www.gnu.org/licenses/>.

.. _reference/reference:

.. currentmodule:: iactsim

Reference manual
================

*Imaging Atmospheric Cherenkov Telescopes*
------------------------------------------
.. automodule:: iactsim
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*optics*
--------
.. automodule:: iactsim.optics
   :members:
   :inherited-members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*optics.ray_tracing*
^^^^^^^^^^^^^^^^^^^^
.. automodule:: iactsim.optics.ray_tracing
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*optics.transforms*
^^^^^^^^^^^^^^^^^^^
.. automodule:: iactsim.optics.transforms
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*optics.sources*
^^^^^^^^^^^^^^^^
.. automodule:: iactsim.optics.sources
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*optics.utils*
^^^^^^^^^^^^^^
.. automodule:: iactsim.optics.utils
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*optics.visualization*
^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: iactsim.optics.visualization
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*electronics*
-------------
.. automodule:: iactsim.electronics
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*electronics.signals*
^^^^^^^^^^^^^^^^^^^^^
.. automodule:: iactsim.electronics.signals
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

.. automodule:: iactsim.electronics.signals.discriminator_signals
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

.. automodule:: iactsim.electronics.signals.sipm_signals
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

.. automodule:: iactsim.electronics.signals.sampling_signals
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

.. automodule:: iactsim.electronics.signals.trigger_logic
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*electronics.signals.sources*
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. automodule:: iactsim.electronics.sources
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*io*
----
.. automodule:: iactsim.io
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*visualization*
---------------
.. automodule:: iactsim.visualization
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*utils*
-------
.. automodule:: iactsim.utils
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*models*
--------
.. automodule:: iactsim.models
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*models.astri*
^^^^^^^^^^^^^^
.. automodule:: iactsim.models.astri
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

*iactxx*
--------
.. automodule:: iactsim.iactxx
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary:

.. automodule:: iactsim.iactxx.io
   :members:
   :no-undoc-members:
   :imported-members:
   :autosummary: